Page 161 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 161

Home

    past ages answers with a resounding, "No!" In his well
    documented book Global Tyranny. . . Step By Step: The
    United Nations and the Emerging New World Order
    William F. Jasper refers to a study done by Professor R.
    J. Rummel about the human cost of 20th century
    totalitarianism. Dr. Rummel's investigation proved that,
    during the 20th century, and independent of war, all
    powerful governments have murdered over 119,000,000
    of their own people. By comparison, the number killed
    on the battle field numbered approximately 35,000,000.
    This means that the total killed by governments in cold
    blood was almost four times that of war. William Jasper

    Absolutist govemments ... are not only many times
    deadlier than war, but are themselves the major factor
    causing war and other forms of violent conflict. They are
    a major cause of militarism. Indeed, absolutism, not war,
    is mankind's deadliest scourge of all.

    able to obtain a monopoly over military power, then,
    "nothing will be restrained from them, which they have
    imagined to do." This danger to mankind was one of the
    reasons that the builders of the Tower of Babel were

    stopped in chapter eleven of Genesis.
    It is certain that a New World Order under the United

    Nations would mean the suppression of our God given
    rights protected by the U. S. Constitution, and the

    156

    The Secret Side of History

    quotes Dr. Rummel as stating:

    The United Nations is not about "Peace and World

    Brotherhood." It is about war. If the War-makers are